@@ -12,16 +12,19 @@ class PreemptableIterator(ABC):
         """Get the name of the iterator, as used in the plan serialization protocol"""
         pass
 
+    @abstractmethod
+    def next_stage(self, mappings: Dict[str, str]):
+        """Propagate mappings to the bottom of the pipeline in order to compute nested loop joins"""
+        pass
+
     @abstractmethod
     async def next(self) -> Optional[Dict[str, str]]:
         """Get the next item from the iterator, following the iterator protocol.
 
-        This function may contains `non interruptible` clauses which must 
+        This function may contains `non interruptible` clauses which must
         be atomically evaluated before preemption occurs.
 
         Returns: A set of solution mappings, or `None` if none was produced during this call.
-
-        Throws: `StopAsyncIteration` if the iterator cannot produce more items.
         """
         pass
 
